run

Function run 

pub async fn run()
Starts all Sentinel services and runs until one exits or shutdown is requested.

Panics

Panics when required configuration is missing or invalid, startup state cannot be initialized, or the metrics/tracing recorders cannot be installed.